@@ -111,7 +111,7 @@ class notion_connector:
 		ret = []
 		for line in data:
 			data_line = {
-				'page_id' : line['id']
+				'page_id' : line['id'],
 				'properties' : {}
 			}
 			for i in line['properties'].items():
